==> core-react-0.8.0.tgz: package/es/Tabs/Tab.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import invariant from 'invariant';
import Button from '../Button';

var Tab = /*#__PURE__*/function (_React$Component) {
  _inherits(Tab, _React$Component);

  function Tab() {
    _classCallCheck(this, Tab);

    return _possibleConstructorReturn(this, _getPrototypeOf(Tab).apply(this, arguments));
  }

  _createClass(Tab, [{
    key: "handleClick",
    value: function handleClick(index, e) {
      e.preventDefault();
      var tabs = this.context.tabs;

      if (!('activeKey' in this.props)) {
        tabs.setState({
          activeIndex: index
        });
      }

      tabs.props.onChange && tabs.props.onChange(index, this.props.activeKey);
    }
  }, {
    key: "onClose",
    value: function onClose(index, e) {
      e.preventDefault();
      e.stopPropagation();

      var _onClose = this.context.tabs.props.onClose || this.context.tablist.onClose;

      _onClose && _onClose(index, this.props.activeKey);
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          children = _this$props.children,
          className = _this$props.className,
          activeKey = _this$props.activeKey,
          closeable = _this$props.closeable,
          other = _objectWithoutProperties(_this$props, ["children", "className", "activeKey", "closeable"]);

      var tabs = this.context.tabs;
      var index = tabs.tabCount++;
      'activeKey' in tabs.props && invariant('activeKey' in this.props, 'You set `activeKey` for Tabs but no `activeKey` for Tab');
      var isActive;

      if ('activeKey' in this.props) {
        isActive = activeKey === tabs.props.activeKey;
      } else {
        isActive = index === tabs.state.activeIndex;
      }

      return React.createElement("li", _extends({
        className: cx("".concat("waui", "-tabs__tab"), _defineProperty({}, "".concat("waui", "-tabs__tab_active"), isActive), className)
      }, other), React.createElement("a", {
        href: "",
        onClick: this.handleClick.bind(this, index),
        draggable: "false"
      }, React.createElement("span", {
        className: "".concat("waui", "-tabs__tab-content")
      }, children), closeable && React.createElement(Button, {
        icon: "close",
        size: "sm",
        className: "".concat("waui", "-tabs__tab-close"),
        onClick: this.onClose.bind(this, index)
      })));
    }
  }]);

  return Tab;
}(React.Component);

Tab.contextTypes = {
  tabs: PropTypes.object,
  tablist: PropTypes.object
};
Tab.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** Corresponds to the Tabs `activeKey` */
  activeKey: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),

  /** Whether to display the close button, default value is `false` */
  closeable: PropTypes.bool
};
export default Tab;

==> core-react-0.8.2.tgz: package/es/Tabs/Tab.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import invariant from 'invariant';
import Button from '../Button';

var Tab = /*#__PURE__*/function (_React$Component) {
  _inherits(Tab, _React$Component);

  function Tab() {
    _classCallCheck(this, Tab);

    return _possibleConstructorReturn(this, _getPrototypeOf(Tab).apply(this, arguments));
  }

  _createClass(Tab, [{
    key: "handleClick",
    value: function handleClick(index, e) {
      e.preventDefault();
      var tabs = this.context.tabs;

      if (!('activeKey' in this.props)) {
        tabs.setState({
          activeIndex: index
        });
      }

      tabs.props.onChange && tabs.props.onChange(index, this.props.activeKey);
    }
  }, {
    key: "onClose",
    value: function onClose(index, e) {
      e.preventDefault();
      e.stopPropagation();

      var _onClose = this.context.tabs.props.onClose || this.context.tablist.onClose;

      _onClose && _onClose(index, this.props.activeKey);
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          children = _this$props.children,
          className = _this$props.className,
          activeKey = _this$props.activeKey,
          closeable = _this$props.closeable,
          other = _objectWithoutProperties(_this$props, ["children", "className", "activeKey", "closeable"]);

      var tabs = this.context.tabs;
      var index = tabs.tabCount++;
      'activeKey' in tabs.props && invariant('activeKey' in this.props, 'You set `activeKey` for Tabs but no `activeKey` for Tab');
      var isActive;

      if ('activeKey' in this.props) {
        isActive = activeKey === tabs.props.activeKey;
      } else {
        isActive = index === tabs.state.activeIndex;
      }

      return (/*#__PURE__*/React.createElement("li", _extends({
          className: cx("".concat("waui", "-tabs__tab"), _defineProperty({}, "".concat("waui", "-tabs__tab_active"), isActive), className)
        }, other), /*#__PURE__*/React.createElement("a", {
          href: "",
          onClick: this.handleClick.bind(this, index),
          draggable: "false"
        }, /*#__PURE__*/React.createElement("span", {
          className: "".concat("waui", "-tabs__tab-content")
        }, children), closeable && /*#__PURE__*/React.createElement(Button, {
          icon: "close",
          size: "sm",
          className: "".concat("waui", "-tabs__tab-close"),
          onClick: this.onClose.bind(this, index)
        })))
      );
    }
  }]);

  return Tab;
}(React.Component);

Tab.contextTypes = {
  tabs: PropTypes.object,
  tablist: PropTypes.object
};
Tab.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** Corresponds to the Tabs `activeKey` */
  activeKey: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),

  /** Whether to display the close button, default value is `false` */
  closeable: PropTypes.bool
};
export default Tab;
